@@ -6,7 +6,7 @@ binDir="debian/tmp/usr/bin/"
 mkdir -p $binDir
 cp theremin $binDir
 
-dtDir="debian/tmp/usr/share/applications/hildon"
+dtDir="debian/tmp/usr/share/applications/hildon/"
 mkdir -p $dtDir
 cp maemo_files/theremin.desktop $dtDir
 
@@ -14,6 +14,15 @@ srvDir="debian/tmp/usr/share/dbus-1/services/"
 mkdir -p $srvDir
 cp maemo_files/theremin.service $srvDir
 
+iconDirScalable="debian/tmp/usr/share/icons/hicolor/scalable/hildon/"
+mkdir -p $iconDirScalable
+cp gfx/icon_64x64.png $iconDirScalable/theremin.png
+
+iconDir26x26="debian/tmp/usr/share/icons/hicolor/26x26/hildon/"
+mkdir -p $iconDir26x26
+cp gfx/icon_26x26.png $iconDir26x26/theremin.png
+
+
 
 #create dir where the output 'control' will be placed
 mkdir -p debian/tmp/DEBIAN
@@ -24,4 +33,4 @@ dpkg-shlibdeps $binDir/theremin
 #generate final control file
 dpkg-gencontrol
 
-dpkg -b debian/tmp ../theremin_1.3.0-2_armel.deb
+dpkg -b debian/tmp ../theremin_1.4.0-1_armel.deb
