@@ -34,6 +34,8 @@ THE SOFTWARE. */
 #include <ting/math.hpp>
 #include <ting/types.hpp>
 
+
+
 using namespace aumiks;
 
 
@@ -54,11 +56,11 @@ bool SineWaveInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 		switch(this->envPhase){
 			case ATTACK:
 				for(; i < mixBuf.Size();){
-					float attack = this->curTime / this->attackTime;
+					real attack = this->curTime / this->attackTime;
 					this->releaseFromLevel = attack;
-					s32 smp = s32(float(0x7fff) * attack * sin(this->curPhase));
-					this->curPhase += 2 * DPi<float>() * this->frequency * (1.0f / float(44100));
-					this->curTime += 1.0f / float(44100);
+					s32 smp = s32(real(0x7fff) * attack * ting::Sin(this->curPhase));
+					this->curPhase += this->phaseStep;
+					this->curTime += real(1000.0f / 44100.0f);
 
 					//interpolate volume
 					ting::u8 vol = ting::u8(startVolume + ((endVolume - startVolume) * i) / mixBuf.Size());
@@ -82,11 +84,11 @@ bool SineWaveInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 				break;
 			case DECAY:
 				for(; i < mixBuf.Size();){
-					float decay = float(1) - (1 - this->sustainLevel) * (this->curTime / this->decayTime);
+					real decay = real(1) - (real(1) - this->sustainLevel) * (this->curTime / this->decayTime);
 					this->releaseFromLevel = decay;
-					s32 smp = s32(float(0x7fff) * decay * sin(this->curPhase));
-					this->curPhase += 2 * DPi<float>() * this->frequency * (1.0f / float(44100));
-					this->curTime += 1.0f / float(44100);
+					s32 smp = s32(real(0x7fff) * decay * ting::Sin(this->curPhase));
+					this->curPhase += this->phaseStep;
+					this->curTime += real(1000.0f / 44100.0f);
 
 					//interpolate volume
 					ting::u8 vol = ting::u8(startVolume + ((endVolume - startVolume) * i) / mixBuf.Size());
@@ -118,14 +120,14 @@ bool SineWaveInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 				}else{
 					this->releaseFromLevel = this->sustainLevel;
 					for(; i < mixBuf.Size();){
-						s32 smp = s32(0x7fff * this->sustainLevel * sin(this->curPhase));
-						this->curPhase += 2 * DPi<float>() * this->frequency * (1.0f / float(44100));
+						s32 smp = s32(real(0x7fff) * this->sustainLevel * ting::Sin(this->curPhase));
+						this->curPhase += this->phaseStep;
 	//					this->curTime += 1.0f / float(44100);
 				//		TRACE(<<"t =" << this->t)
 				//		TRACE(<<"smp =" << smp)
 
 						//interpolate volume
-						ting::u8 vol = ting::u8(startVolume + ((endVolume - startVolume) * i) / mixBuf.Size());
+						ting::u8 vol = ting::u8(startVolume + (endVolume - startVolume) * i / mixBuf.Size());
 
 						//apply volume
 						smp = (smp * vol) / 0xff;
@@ -138,17 +140,17 @@ bool SineWaveInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 				}
 
 				{
-					float numPeriods = this->curPhase / (2 * DPi<float>());
-					this->curPhase -= float(ting::uint(numPeriods)) * 2 * DPi<float>();
+					real numPeriods = this->curPhase / D2Pi<real>();
+					this->curPhase -= real(int(numPeriods)) * D2Pi<real>();
 				}
 
 				break;//~switch
 			case RELEASE:
 				for(; i < mixBuf.Size();){
-					float release = this->releaseFromLevel * (1 - this->curTime / this->releaseTime);
-					s32 smp = s32(float(0x7fff) * release * sin(this->curPhase));
-					this->curPhase += 2 * DPi<float>() * this->frequency * (1.0f / float(44100));
-					this->curTime += 1.0f / float(44100);
+					real release = this->releaseFromLevel * (real(1) - this->curTime / this->releaseTime);
+					s32 smp = s32(real(0x7fff) * release * ting::Sin(this->curPhase));
+					this->curPhase += this->phaseStep;
+					this->curTime += real(1000.0f / 44100.0f);
 
 					//interpolate volume
 					ting::u8 vol = ting::u8(startVolume + ((endVolume - startVolume) * i) / mixBuf.Size());
