@@ -31,6 +31,8 @@ THE SOFTWARE. */
 #ifndef M_Synth_hpp
 #define	M_Synth_hpp
 
+#include <ting/Fixed.hpp>
+
 #include "../aumiks.hpp"
 
 #include "PluckedString.hpp"
@@ -99,16 +101,26 @@ public:
 
 	//override
 	Ref<Instrument::Channel> CreateChannel();
+
+	static inline ting::Ref<PluckedStringInstrument> New(){
+		return ting::Ref<PluckedStringInstrument>(new PluckedStringInstrument());
+	}
 };
 
 
 class SineWaveInstrument : public Instrument{
 public:
 
-	class Channel : public Instrument::Channel{
-		float curPhase;
+#ifdef M_USE_FIXED_POINT
+	typedef Fixed<13> real;
+#else
+	typedef float real;
+#endif
 
-		float curTime;
+	class Channel : public Instrument::Channel{
+		real curPhase;
+
+		real curTime; //in milliseconds
 		enum EEnvelopePhase{
 			ATTACK,
 			DECAY,
@@ -116,13 +128,13 @@ public:
 			RELEASE
 		} envPhase;
 
-		float frequency;
-		float attackTime;//s
-		float decayTime;//s
-		float sustainLevel;
-		float releaseTime;//s
+		real phaseStep;// (Hz / 44100) * 2pi
+		real attackTime;//ms
+		real decayTime;//ms
+		real sustainLevel;
+		real releaseTime;//ms
 
-		float releaseFromLevel;
+		real releaseFromLevel;
 	public:
 
 		Channel() :
@@ -134,12 +146,13 @@ public:
 		};
 
 		//override
+		// freq in Hz
 		void SetFrequency(float freq){
-			this->frequency = freq;
-			this->attackTime = 20.0f/freq;
-			this->decayTime = 20.0f/freq;
-			this->sustainLevel = 0.4;
-			this->releaseTime = 30.0f/freq;
+			this->phaseStep = D2Pi<real>() * real(freq) / real(44100);
+			this->attackTime = 1000.0f * 20.0f / freq;
+			this->decayTime = 1000.0f * 20.0f / freq;
+			this->sustainLevel = 0.4f;
+			this->releaseTime = 1000.0f * 30.0f / freq;
 		};
 
 	private:
@@ -149,6 +162,9 @@ public:
 
 	Ref<Instrument::Channel> CreateChannel();
 
+	static inline ting::Ref<SineWaveInstrument> New(){
+		return ting::Ref<SineWaveInstrument>(new SineWaveInstrument());
+	}
 };
 
 }//~namespace
