@@ -27,13 +27,49 @@ THE SOFTWARE. */
  * Created on February 23, 2009, 7:49 PM
  */
 
-#ifndef M_stdafx_hpp
-#define	M_stdafx_hpp
+#pragma once
+
+#include <string>
 
 #include <ting/types.hpp>
 
 inline ting::uint DFingerFriendlyMinSize(){
 	return 60;
-};
+}
 
-#endif//~once
+
+
+inline std::string DHost(){
+	return "188.120.242.144";
+//	return "localhost";
+}
+
+
+
+inline ting::u16 DPort(){
+	return 13666;
+}
+
+
+
+
+//strings
+inline const char* DStrOffline(){
+	return "Offline";
+}
+
+inline const char* DStrConnecting(){
+	return "Connecting...";
+}
+
+inline const char* DStrConnected(){
+	return "Connected";
+}
+
+inline const char* DStrLoggingIn(){
+	return "Logging in...";
+}
+
+inline const char* DStrLoggedIn(){
+	return "Logged in";
+}
